==> haskell-monads-tf-0.1.0.3-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monads-tf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monads-tf
version:              0.1.0.3
visibility:           public
id:                   monads-tf-0.1.0.3-FhjV1qTiZJq2D5pKEDYJP3
key:                  monads-tf-0.1.0.3-FhjV1qTiZJq2D5pKEDYJP3
license:              BSD-3-Clause
maintainer:           Ross Paterson <ross@soi.city.ac.uk>
author:               Andy Gill
synopsis:             Monad classes, using type families
description:
    Monad classes using type families, with instances for various
    monad transformers, inspired by the paper /Functional Programming
    with Overloading and Higher-Order Polymorphism/, by Mark P
    Jones, in /Advanced School of Functional Programming/, 1995
    (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).

    This package is almost a compatible replacement for the @mtl-tf@ package.

category:             Control
abi:                  a12ba7ff7fdcde5015bd6e6b9e20bbc1
exposed-modules:
    Control.Monad.Cont Control.Monad.Cont.Class Control.Monad.Error
    Control.Monad.Error.Class Control.Monad.Identity Control.Monad.List
    Control.Monad.RWS Control.Monad.RWS.Class Control.Monad.RWS.Lazy
    Control.Monad.RWS.Strict Control.Monad.Reader
    Control.Monad.Reader.Class Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict

import-dirs:          /usr/lib/ghc-9.0.1/site-local/monads-tf-0.1.0.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/monads-tf-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/monads-tf-0.1.0.3
hs-libraries:         HSmonads-tf-0.1.0.3-FhjV1qTiZJq2D5pKEDYJP3
depends:              base-4.15.0.0 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-monads-tf/html/monads-tf.haddock
haddock-html:         /usr/share/doc/haskell-monads-tf/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monads-tf-0.1.0.3-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monads-tf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monads-tf
version:              0.1.0.3
visibility:           public
id:                   monads-tf-0.1.0.3-LS0v3a5UuzO9oiSqbetO8t
key:                  monads-tf-0.1.0.3-LS0v3a5UuzO9oiSqbetO8t
license:              BSD-3-Clause
maintainer:           Ross Paterson <ross@soi.city.ac.uk>
author:               Andy Gill
synopsis:             Monad classes, using type families
description:
    Monad classes using type families, with instances for various
    monad transformers, inspired by the paper /Functional Programming
    with Overloading and Higher-Order Polymorphism/, by Mark P
    Jones, in /Advanced School of Functional Programming/, 1995
    (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).

    This package is almost a compatible replacement for the @mtl-tf@ package.

category:             Control
abi:                  bbb8e7baf3bebdfda8c0e13ee2beb3ee
exposed-modules:
    Control.Monad.Cont Control.Monad.Cont.Class Control.Monad.Error
    Control.Monad.Error.Class Control.Monad.Identity Control.Monad.List
    Control.Monad.RWS Control.Monad.RWS.Class Control.Monad.RWS.Lazy
    Control.Monad.RWS.Strict Control.Monad.Reader
    Control.Monad.Reader.Class Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict

import-dirs:          /usr/lib/ghc-9.0.2/site-local/monads-tf-0.1.0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/monads-tf-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/monads-tf-0.1.0.3
hs-libraries:         HSmonads-tf-0.1.0.3-LS0v3a5UuzO9oiSqbetO8t
depends:              base-4.15.1.0 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-monads-tf/html/monads-tf.haddock
haddock-html:         /usr/share/doc/haskell-monads-tf/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
